#define STATUS "-stable"		/* stable branch */
#if 0
#define STATUS ""			/* release */
#define STATUS "-beta"			/* just before a release */
#define STATUS "-current"		/* just after a release */
#endif

const char ostype[] = "OpenBSD";
const char osrelease[] = "7.0";
const char osversion[] = "RDROOT.MP#1";
const char sccs[] =
    "    @(#)OpenBSD 7.0" STATUS " (RDROOT.MP) #1: Sun Oct 31 07:33:15 JST 2021\n";
const char version[512] =
    "OpenBSD 7.0" STATUS " (RDROOT.MP) #1: Sun Oct 31 07:33:15 JST 2021\n    kaw@nimbus24.localnet:/opt/fi/7.0/sys/arch/arm64/compile/RDROOT.MP\n";
